@@ -2,7 +2,7 @@
 # ExperimentError Exception, for db errors, etc.
 # ----------------------------------------------
 # Possible ExperimentError values.
-
+from __future__ import generator_stop
 from flask import render_template
 
 
@@ -153,17 +153,23 @@ class ExperimentError(Exception):
             **request.args)
 
 
-class InvalidUsage(Exception):
-    status_code = 400
-
-    def __init__(self, message, status_code=None, payload=None):
-        Exception.__init__(self)
+class ExperimentApiError(Exception):
+    
+    def __init__(self, message, status_code=500, payload=None):
+        super().__init__()
         self.message = message
-        if status_code is not None:
-            self.status_code = status_code
+        self.status_code = status_code
         self.payload = payload
 
     def to_dict(self):
         rv = dict(self.payload or ())
         rv['message'] = self.message
         return rv
+
+
+class InvalidUsageError(ExperimentApiError):
+    
+    def __init__(self, *args, **kwargs):
+        if 'status_code' not in kwargs:
+            kwargs['status_code'] = 400
+        super(InvalidUsageError, self).__init__(*args, **kwargs)
