@@ -93,8 +93,11 @@ class PsiturkNetworkShell(Cmd, object):
                     '- `psiturk server on`',
                     '- `psiturk server off`',
                     '- `psiturk debug -p`'])
-                message = '{}{}'.format(e.message, still_can_do)
+                message = e.message
+                if not self.quiet:
+                    message = '{}{}'.format(message, still_can_do)
                 self.perror(message)
+                sys.exit()
             except PsiturkException as e:
                 self.poutput(e)
 
@@ -146,7 +149,7 @@ class PsiturkNetworkShell(Cmd, object):
         self.quiet = quiet
         self.feedback_to_output = True
 
-        if not self.amt_services_wrapper and not self.quiet:
+        if not self.quiet and not self.amt_services_wrapper:
             sys.exit()
 
         if not self.quiet:
@@ -447,7 +450,6 @@ class PsiturkNetworkShell(Cmd, object):
                 self.maybe_update_hit_tally()
 
             hit_id = create_hit_response.data['hit_id']
-            ad_id = create_hit_response.data['ad_id']
 
             # TODO: "with qualification type ids..."
             self.poutput('\n'.join(['*****************************',
@@ -463,8 +465,8 @@ class PsiturkNetworkShell(Cmd, object):
 
             # Print the Ad Url
             base = self.config.get_ad_url()
-            assignmentid = str(self.random_id_generator()),
-            hitid = str(self.random_id_generator()),
+            assignmentid = str(self.random_id_generator())
+            hitid = str(self.random_id_generator())
             workerid = str(self.random_id_generator())
 
             ad_url = f'{base}?mode={self.mode}&assignmentId=debug{assignmentid}&hitId=debug{hitid}&workerId=debug{workerid}'
